Module implication

Module implication 

Feature implication graph and redundant-combination pruning. Feature implication graph and redundant-combination pruning.

Cargo features can imply other features (e.g. B = ["A"]). When this happens, the combination [A, B] resolves to the same effective feature set as [B] alone. This module detects and prunes such redundant combinations.

Structs

PruneResult
Result of partitioning feature combinations via implied-feature pruning.
PrunedCombination
A feature combination that was pruned because another (smaller) combination resolves to the same effective feature set.

Functions

maybe_prune
Apply implied-feature pruning if the config enables it, otherwise return combos unchanged.